#
# spec file for package virt-sandbox
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define libvirt_version 1.0.2
%define soname 1_0-5 

Name:           virt-sandbox
Version:        0.6.0
Release:        8.3
Url:            http://libvirt.org/
Summary:        Libvirt application sandbox framework
License:        LGPL-2.0+
Group:          System/Management
Source0:        ftp://libvirt.org/libvirt/sandbox/libvirt-sandbox-%{version}.tar.gz
Source1:        %{name}.rpmlintrc

# Upstream patches
Patch0:         dhcp-fix.patch
Patch1:         f24d003b-sync-unmount-shutdown.patch

# Patches pending upstream review

# Need to go upstream

# Our patches
Patch200:       no-libexec.patch

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  glib2-devel >= 2.32.0
BuildRequires:  glibc-static
BuildRequires:  gobject-introspection-devel
BuildRequires:  gtk-doc
BuildRequires:  intltool
BuildRequires:  libselinux-devel
BuildRequires:  libtool
BuildRequires:  libvirt-glib-devel >= 0.2.1
BuildRequires:  perl
BuildRequires:  zlib-devel-static
Requires:       rpm-python
# For virsh lxc-enter-namespace command
Requires:       libvirt-client >= %{libvirt_version}
Requires:       python3-gobject
Requires:       systemd >= 198
# Requires: libselinux-python
Requires:       cron
Requires:       libvirt-sandbox-%{soname} = %{version}-%{release}

%package -n libvirt-sandbox-%{soname}
Summary:        Libvirt application sandbox framework libraries
Group:          Development/Libraries/C and C++
# So we get the full libvirtd daemon, not just client libs
Requires:       libvirt-daemon-lxc >= %{libvirt_version}
Requires:       libvirt-daemon-qemu >= %{libvirt_version}

%package -n typelib-1_0-LibvirtSandbox-1_0
Summary:        GLib and GObject mapping of libvirt-sandbox - gi-bindings
Group:          System/Libraries

%package -n libvirt-sandbox-devel
Summary:        Libvirt application sandbox framework development files
Group:          Development/Libraries/C and C++
Requires:       libvirt-sandbox-%{soname} = %{version}-%{release}

%description
This package provides a command for running applications within
a sandbox using libvirt.

%description -n libvirt-sandbox-%{soname}
This package provides a framework for building application sandboxes
using libvirt.

%description -n libvirt-sandbox-devel
This package provides development header files and libraries for
the libvirt sandbox

%description -n typelib-1_0-LibvirtSandbox-1_0
This package provides Gnome-introspection bindings for building
applications within a sandbox using libvirt.

%prep
%setup -q -n libvirt-sandbox-%{version}
%patch0 -p1
%patch1 -p1
%patch200 -p1

%build
# We may have a more recent version of automake when building
# than the one used to autoconfigure the project for the distribution
# Just make sure the files are sync'ed with our version
autoreconf -f -i
%configure --enable-introspection --disable-static --without-lzma
make V=1 %{?_smp_mflags}

%install
rm -rf $RPM_BUILD_ROOT
chmod a-x examples/*.py examples/*.pl examples/*.js
chmod a-x bin/virt-sandbox-service-bash-completion.sh
%makeinstall
rm -f $RPM_BUILD_ROOT%{_libdir}/libvirt-sandbox-1.0.a
rm -f $RPM_BUILD_ROOT%{_libdir}/libvirt-sandbox-1.0.la

%find_lang libvirt-sandbox

%clean
rm -rf $RPM_BUILD_ROOT

%post -n libvirt-sandbox-%{soname} -p /sbin/ldconfig
%postun -n libvirt-sandbox-%{soname} -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%{_datadir}/bash-completion/completions/virt-sandbox-service
%config(noreplace) %{_sysconfdir}/cron.daily/virt-sandbox-service.logrotate
%dir %{_sysconfdir}/libvirt-sandbox/services
%{_bindir}/virt-sandbox
%{_bindir}/virt-sandbox-service
%{_libexecdir}/virt-sandbox-service-util
%{_mandir}/man1/virt-sandbox.1*
%{_mandir}/man1/virt-sandbox-service.1*
%{_mandir}/man1/virt-sandbox-service-*.1*

%files -n libvirt-sandbox-%{soname} -f libvirt-sandbox.lang
%defattr(-,root,root,-)
%doc README COPYING AUTHORS ChangeLog NEWS
%dir %{_sysconfdir}/libvirt-sandbox
%dir %{_sysconfdir}/libvirt-sandbox/scratch
%config %{_sysconfdir}/libvirt-sandbox/scratch/README
%{_libexecdir}/libvirt-sandbox-init-common
%{_libexecdir}/libvirt-sandbox-init-lxc
%{_libexecdir}/libvirt-sandbox-init-qemu
%{_libdir}/libvirt-sandbox-1.0.so.*

%files -n typelib-1_0-LibvirtSandbox-1_0
%defattr(-,root,root,-)
%{_libdir}/girepository-1.0/LibvirtSandbox-1.0.typelib

%files -n libvirt-sandbox-devel
%defattr(-,root,root,-)
%doc examples/virt-sandbox.pl
%doc examples/virt-sandbox.py
%doc examples/virt-sandbox.js
%doc examples/virt-sandbox-mkinitrd.py
%{_libdir}/libvirt-sandbox-1.0.so
%{_libdir}/pkgconfig/libvirt-sandbox-1.0.pc
%dir %{_includedir}/libvirt-sandbox-1.0
%dir %{_includedir}/libvirt-sandbox-1.0/libvirt-sandbox
%{_includedir}/libvirt-sandbox-1.0/libvirt-sandbox/libvirt-sandbox.h
%{_includedir}/libvirt-sandbox-1.0/libvirt-sandbox/libvirt-sandbox-*.h
%{_datadir}/gir-1.0/LibvirtSandbox-1.0.gir
%{_datadir}/gtk-doc/html/Libvirt-sandbox

%changelog
* Wed Sep 16 2015 cbosdonnat@suse.com
- Synchronize and unmount disks during shutdown. bsc#946040
  f24d003b-sync-unmount-shutdown.patch
* Fri Aug 21 2015 cbosdonnat@suse.com
- Make sure the af_packet module is loaded for KVM sandbox with
  user network setup to work. dhcp-fix.patch. boo#942733
* Wed Jul  1 2015 cbosdonnat@suse.com
- Updated to version 0.6.0:
  * Prevent use of virt-sandbox-service as non-root upfront
  * Fix misc memory leaks
  * Block SIGHUP from the dhclient binary to prevent accidental death if the controlling terminal is closed & reopened
  * Add support for re-creating libvirt XML from sandbox config to facilitate upgrades
  * Add ability to set filters on network interfaces
  * Search /usr/lib instead of /lib for systemd unit files, as the former is the canonical location even when / and /usr are merged
  * Only set SELinux labels on hosts that support SELinux
  * Explicitly link to selinux, instead of relying on indirect linkage
  * Update compiler warning flags
  * Fix misc docs comments
  * Don’t assume use of SELinux in virt-sandbox-service
  * Fix path checks for SUSE in virt-sandbox-service
  * Add support for AppArmour profiles
  * Mount /var after other FS to ensure host image is available
  * Ensure state/config dirs can be accessed when QEMU is running non-root for qemu:///system
  * Fix mounting of host images in QEMU sandboxes
  * Mount images as ext4 instead of ext3
  * Allow use of non-raw disk images as filesystem mounts
  * Check if required static libs are available at configure time to prevent silent fallback to shared linking
  * Require libvirt-glib >= 0.2.1
  * Add support for loading lzma and gzip compressed kmods
  * Check for support libvirt URIs when starting guests to ensure clear error message upfront
  * Add LIBVIRT_SANDBOX_INIT_DEBUG env variable to allow debugging of kernel boot messages and sandbox init process setup
  * Add support for exposing block devices to sandboxes with a predictable name under /dev/disk/by-tag/TAGNAME
  * Use devtmpfs instead of tmpfs for auto-populating /dev in QEMU sandboxes
  * Allow setup of sandbox with custom root filesystem instead of inheriting from host’s root. (boo#936841)
  * Allow execution of apps from non-matched ld-linux.so / libc.so, eg executing F19 binaries on F22 host
  * Use passthrough mode for all QEMU filesystems
- Removed now useless patches:
  * 2053d552-service-mount-var-last.patch
  * 6ec0460c-apparmor-support.patch
  * 87a9b5cc-lib-prefix-fix.patch
  * 92412e9c-systemd-path-fix.patch
  * 945e8e71-selinux-only-if-supported.patch
  * a54e094b-service-suse-paths.patch
  * baf47f5b-service-check-secmodel.patch
* Tue Nov 18 2014 cbosdonnat@suse.com
- Add AppArmor support. bsc#909249.
  6ec0460c-apparmor-support.patch
- virt-sandbox-service: /var needs to be the last to be mounted
  bsc#909249. 2053d552-service-mount-var-last.patch
- Renamed systemd-path-fix.patch into 92412e9c-systemd-path-fix.patch
  as patch went upstream
* Wed Oct  1 2014 cbosdonnat@suse.com
- Run autoreconf before configure when building to avoid problems
  with more recent versions of autotools
* Tue Jul 15 2014 cbosdonnat@suse.com
- bnc#887145: fix hardcoded /usr/libexec, use /usr/lib instead:
  no-libexec.patch
  Fixed systemd path: systemd-path-fix.patch
- Moved patches as they were merged upstream:
  * service-check-secmodel.patch renamed into
    baf47f5b-service-check-secmodel.patch
  * service-suse-paths.patch renamed into
    a54e094b-service-suse-paths.patch
* Mon Jul  7 2014 cbosdonnat@suse.com
- bnc#885464: make virt-sandbox-service not check for dynamic security
  label if libvirt doesn't support selinux.
- Fixed a few paths problems in virt-sandbox-service
- added patches:
  * service-check-secmodel.patch
  * service-suse-paths.patch
* Wed Jun 25 2014 cbosdonnat@suse.com
- Renamed lib-prefix-fix.patch into 87a9b5cc-lib-prefix-fix.patch as
  the patch has been integrated upstream.
- Removed selinux-only-if-supported.patch and created
  945e8e71-selinux-only-if-supported.patch with the version of the
  patch that was integrated upstream.
* Wed Jun  4 2014 cbosdonnat@suse.com
- selinux-only-if-supported.patch: only set the selinux security
  label if selinux is supported by the host. bnc#878048
* Tue May 13 2014 cbosdonnat@suse.com
- lib-prefix-fix.patch: don't look for unit files in /lib, but rather
  /usr/lib. bnc#875642
* Mon Dec 23 2013 cbosdonnat@suse.com
- libvirt-sandbox 0.5.1
